import { FormSchema } from "../../src/pages/Contact/FormSchema";
import * as yup from "yup";

jest.mock('react-native/Libraries/Animated/src/NativeAnimatedHelper');

const fullNameMock = 'Fulano da Silva'
const emailMock = 'ages@gmail.com'
const phoneNumberMock = 51123456789
const messageMock = 'this is a message'


describe("FormSchema required name validation", () => {

    it('should verify fullname field is not empty', () => {
        const errors = FormSchema.validate({
            fullName: '',
            email: emailMock,
            phoneNumber: phoneNumberMock,
            message: messageMock
        }).catch(function (err) {

            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Campo obrigatório')

        });
    });

});

describe("FormSchema required name validation", () => {

    it('should verify fullname size should not be lower than 10', () => {
        const errors = FormSchema.validate({
            fullName: '123456789',
            email: emailMock,
            phoneNumber: phoneNumberMock,
            message: messageMock
        }).catch(function (err) {

            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Insira o nome completo')
        });
    });

});

describe("FormSchema required email validation", () => {

    it('should verify email field is not empty', () => {
        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: '',
            phoneNumber: phoneNumberMock,
            message: messageMock
        }).catch(function (err) {

            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Campo obrigatório')
        });
    });

});

describe("FormSchema required email validation", () => {

    it('should verify email format', () => {

        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: 'email',
            phoneNumber: phoneNumberMock,
            message: messageMock
        }).catch(function (err) {
            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Email inválido')
        });
    });

});

describe("FormSchema required phoneNumber validation", () => {

    it('should verify phoneNumber format', () => {

        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: emailMock,
            phoneNumber: '00000000000',
            message: messageMock
        }).catch(function (err) {
            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Formato inválido')
        });
    });

});

describe("FormSchema required phoneNumber validation", () => {

    it('should verify phoneNumber should not be empty', () => {

        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: emailMock,
            phoneNumber: '',
            message: messageMock
        }).catch(function (err) {
            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Campo obrigatório')
        });
    });

});

describe("FormSchema required phoneNumber validation", () => {

    it('should verify phoneNumber size must be 11', () => {

        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: emailMock,
            phoneNumber: '5194567890',
            message: messageMock
        }).catch(function (err) {
            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('São necessários 11 números')
        });
    });

});

describe("FormSchema required message validation", () => {

    it('should verify message should not be empty', () => {

        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: emailMock,
            phoneNumber: phoneNumberMock,
            message: ''
        }).catch(function (err) {
            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Campo obrigatório')
        });
    });

});

describe("FormSchema required message validation", () => {

    it('should verify message size should be 10 or higher', () => {

        const errors = FormSchema.validate({
            fullName: fullNameMock,
            email: emailMock,
            phoneNumber: phoneNumberMock,
            message: '123456789'
        }).catch(function (err) {
            expect(err).toBe(yup.ValidationError)
            expect(err.message).toBe('Sua mensagem deve conter no mínimo 10 caracteres')
        });
    });

});