import React from "react";
import { NavigationContainer } from "@react-navigation/native";
import { createDrawerNavigator } from "@react-navigation/drawer";
import { Screens } from "./interfaces/NavigationProps/NavigationProps.interface";

import DrawerContent from "./components/DrawerContent/DrawerContent";
import {
	authScreens,
	userScreens,
	authUserScreens,
	coreScreens,
	commonScreens,
} from './pages/Router';

const Drawer = createDrawerNavigator();

export default function Navigation() {
	return (
		<NavigationContainer>
			<Drawer.Navigator initialRouteName={Screens.Home} screenOptions={{headerShown: false}} drawerContent={(props) => <DrawerContent {...props} />}>
				{
					Object.entries({
						...authScreens,
						...userScreens,
						...authUserScreens,
						...coreScreens,
						...commonScreens,
					}).map(([name, { component }]) => (
						<Drawer.Screen key={name} name={name} component={component}/>
					))
				}
			</Drawer.Navigator>
		</NavigationContainer>
	);
}
