import React from "react";
import Text from "../Text/Text";
import { CarouselProps } from "../../interfaces/CarouselProps/CarouselProps.interface";
import {
	View,
	Image,
	ScrollView,
	Dimensions,
} from "react-native";

const width = Dimensions.get("window").width;
const height = Dimensions.get("window").height * 0.3;

export default class Carousel extends React.Component<CarouselProps> {
	state = {
		active: 0,
	};

	change = ( {nativeEvent} : {nativeEvent:any} ) => {
		const slide = Math.ceil(
			nativeEvent.contentOffset.x / nativeEvent.layoutMeasurement.width
		);
		if (slide !== this.state.active) {
			this.setState({ active: slide });
		}
	};

	render() {
		return (
			<View style={{ width, height }}>
				<ScrollView
					pagingEnabled
					scrollEnabled
					horizontal
					onScroll={this.change}
					showsHorizontalScrollIndicator
					style={{ width, height }}
				>
					{this.props.images?.map((image, index) => (
						<Image
							key={index}
							source={{ uri: image }}
							style={{ width, height, resizeMode: "cover" }}
						/>
					))}
				</ScrollView>
				<View
					style={{
						flexDirection: "row",
						position: "absolute",
						zIndex: 2,
						bottom: 0,
						alignSelf: "center",
					}}
				>
					{this.props.images?.map((i, k) => (
						<Text
							key={k}
							margin="3px"
							iconLeft=""
							iconColor=""
							color={k === this.state.active ? "white" : ""}
						>
							⬤
						</Text>
					))}
				</View>
			</View>
		);
	}
}
