import React, { useEffect, useState } from 'react';

import Picker from '../Picker/Picker'
import TextInput from '../TextInput/TextInput'

import { PickerItems } from '../../interfaces/PickerProps/PickerProps.interface';
import { SearchFilterFormProps } from "../../interfaces/SearchFilterFormProps/SearchFilterFormProps.interface";

import CitiesService from "../../services/CitiesService";
import TypesService from '../../services/TypesService'

export default function SearchFilterForm({ searchParams, onChangeField }: SearchFilterFormProps) {
	const [cities, setCities] = useState<PickerItems[]>([] as PickerItems[])
	const [types, setTypes] = useState<PickerItems[]>([] as PickerItems[])

	async function setUp() {
		const [_cities, _types] = await Promise.all([
			CitiesService.findCities(),
			TypesService.findTypes()
		])
		setCities(_cities.map(({ id, name }) => ({ label: name, value: id })));
		setTypes(_types.map(({ id, name }) => ({ label: name, value: id })));
	}

	useEffect(() => {
		setUp();
	}, [])

	return (
		<>
			<Picker
				items={cities}
				iconLeft="location-on"
				selectedValue={searchParams.city.id}
				onValueChange={(value: string, i: any) => onChangeField({ name: 'city', value: { id: value, name: cities[i].label } })}
			/>

			<Picker
				items={types}
				iconLeft="home"
				selectedValue={searchParams.place.id}
				onValueChange={(value: string, i: any) => onChangeField({ name: 'place', value: { id: value, name: types[i].label } })}
			/>

			<TextInput
				iconLeft="today"
				placeholder="Quando"
				onChangeText={(value: React.SetStateAction<string>) => onChangeField({ name: 'date', value })}
				value={searchParams.date}
			/>

			<TextInput
				iconLeft="people"
				placeholder="Pessoas"
				onChangeText={(value: React.SetStateAction<string>) => onChangeField({ name: 'people', value })}
				value={searchParams.people}
			/>
		</>
	);
}
