import React from "react";
import * as vectorIcons from "@expo/vector-icons";
import * as s from "./styles";
import { InputProps } from "../../interfaces/TextInputProps/TextInputProps.interface";

export default function TextInput ({
	placeholder,
	iconLeft,
	iconRight,
	iconPackage,
	onPressIconLeft,
	onPressIconRight,
	_ref,
	...props
}: InputProps) {
	const [focused, setFocused] = React.useState(false);
	const Icon = iconPackage ? vectorIcons[iconPackage] : vectorIcons.MaterialIcons;
	return (
		<s.Container {...props}>
			{iconLeft && (
				<Icon
					style={{ paddingRight: 7 }}
					name={iconLeft}
					size={24}
					color="black"
					onPress={onPressIconLeft}
				/>
			)}
			<s.TextInput
				{...props}
				ref={_ref}
				clearButtonMode="while-editing"
				onBlur={() => setFocused(false)}
				onFocus={() => setFocused(true)}
				placeholder={placeholder}
				selectTextOnFocus
				focused={focused}
			/>
			{iconRight && (
				<Icon
					style={{ paddingLeft: 10 }}
					name={iconRight}
					size={24}
					color="black"
					onPress={onPressIconRight}
				/>
			)}
		</s.Container>
	);
}
