import React, { useState } from "react";
import { ScrollView, View, TouchableOpacity } from "react-native";
import { HomePageProps } from "../../interfaces/HomePageProps/HomePageProps.interface";
import { InitialValues } from "../../interfaces/SearchParams/SearchParams.interface";
import Title from "../../components/Title/Title";
import Button from "../../components/Button/Button";
import { PageContainer, HomeConainer, Header, Body, Footer, TownImage } from "./styles";
import { SearchFilterFormField } from "../../interfaces/SearchFilterFormProps/SearchFilterFormProps.interface";
import SearchFilterForm from '../../components/SearchFilterForm/SearchFilterForm';
import { Screens } from "../../interfaces/NavigationProps/NavigationProps.interface";

const Home: React.FC<HomePageProps> = ({ navigation }) => {
	const [params, setParams] = useState(InitialValues);

	function handleChangeField({ name, value }: SearchFilterFormField) {
		setParams({ ...params, [name]: value });
	}

	const handleButtonPress = async () => {
		navigation.navigate(Screens.ListPlaces, { specs: params });
	};

	return (
		<PageContainer>
			<TownImage source={require("../../../assets/Login/town.png")} />
			<HomeConainer>
				<Header>
					<Title
						color="primary"
						fontWeight="normal"
						textTransform="uppercase"
						textAlign="center"
					>
						{`O jeito prático de\n reservar espaços`}
					</Title>
				</Header>
				<Body>
					<SearchFilterForm
						searchParams={params}
						onChangeField={handleChangeField}
					/>
				</Body>
				<Footer>
					<Button fontSize="20px" onPress={handleButtonPress}>Buscar Locais</Button>
					<Button
							outlined
							borderColor="white"
							fontWeight="200"
							fontSize="16px"
						>
							Cadastre Seu Espaço
						</Button>
				</Footer>
			</HomeConainer>
		</PageContainer>
	);
}

export default Home;
