import React, { useState } from "react";
import {
	PageContainer,
	TownImage,
	LoginContainer,
	Header,
	Body,
	InputContainer,
	ButtonContainer,
	Line,
	Footer,
	ErroMessage,
	ActivityIndicatorWrapperContainer,
	ModalBackgroundContainer,
} from "./styles";
import TextInput from "../../components/TextInput/TextInput";
import { Alert, Modal, ActivityIndicator } from "react-native";
import UserService from "../../services/UsersService";
import { LoginPageProps } from "../../interfaces/LoginPageProps/LoginPageProps.interface";
import Button from "../../components/Button/Button";
import ButtonGoogle from "../../components/ButtonGoogle/ButtonGoogle";
import Title from "../../components/Title/Title";
import { AntDesign } from "@expo/vector-icons";
import { Screens } from "../../interfaces/NavigationProps/NavigationProps.interface";

const Login: React.FC<LoginPageProps> = ({ navigation }) => {
	const [email, setEmail] = useState("");
	const [password, setPassword] = useState("");
	const [loading, setLoading] = useState(false);
	const [errorText, setErrorText] = useState("");
	const [hidePassword, setVisibilityPassword] = useState(true);
	const iconPassword = !hidePassword ? "eye-off" : "eye";

	const handleHidePassword = async () => {
		setVisibilityPassword(!hidePassword);
	};

	const handleSubmitPress = async () => {
		setErrorText("");
		setLoading(false);

		if (email === "") {
			Alert.alert("Email não preenchido", "Por favor insira um email");
			return;
		}
		if (password === "") {
			Alert.alert("Senha não preenchida", "Por favor insira uma senha");
			return;
		}

		setLoading(true);
		if (await UserService.login(email, password)) {
			UserService.loadUser();
			setLoading(false);
			navigation.navigate(Screens.Home, { specs: null });
		} else {
			setLoading(false);
			setErrorText("Seu email ou senha estão incorretos");
		}
	};

	return (
		<PageContainer>
			<Modal
				transparent={true}
				animationType={"none"}
				visible={loading}
				onRequestClose={() => {
					console.log("close loading modal");
				}}
			>
				<ModalBackgroundContainer>
					<ActivityIndicatorWrapperContainer>
						<ActivityIndicator animating={loading} />
					</ActivityIndicatorWrapperContainer>
				</ModalBackgroundContainer>
			</Modal>
			<TownImage source={require("../../../assets/Login/town.png")} />
			<LoginContainer>
				<Header>
					<Title
						color="primary"
						fontWeight="normal"
						textTransform="uppercase"
						textAlign="center"
					>
						{`O jeito prático de\n reservar espaços`}
					</Title>
				</Header>
				<Body>
					<InputContainer>
						<TextInput
							placeholder="E-mail"
							keyboardType="email-address"
							onChangeText={(value) => setEmail(value)}
						/>
						<TextInput
							placeholder="Senha"
							secureTextEntry={hidePassword}
							onChangeText={(value) => setPassword(value)}
							iconPackage="MaterialCommunityIcons"
							iconRight={iconPassword}
							onPressIconRight={handleHidePassword}
						/>
					</InputContainer>
					{errorText != "" ? <ErroMessage>{errorText}</ErroMessage> : null}
					<ButtonContainer>
						<Button fontSize="20px" onPress={() => handleSubmitPress()}>Entrar</Button>
						<Button
							outlined
							borderColor="white"
							fontWeight="200"
							fontSize="16px"
							onPress={() => {
								navigation.navigate(Screens.RegisterUser);
							}}
						>
							Criar uma conta
						</Button>
					</ButtonContainer>
				</Body>
				<Footer>
					<Line />
					<ButtonGoogle />
				</Footer>
			</LoginContainer>
		</PageContainer>
	);
};

export default Login;
