import React from "react";
import { ScrollView, View } from "react-native";
import Carousel from "../../components/Carousel/Carousel";
import Maps from "../../components/Maps/Maps";
import { colors } from "../../config/Theme";
import {
	PageContainer,
	ButtonContainer,
	ButtonSelected,
	ButtonNoSelected,
	ContainerPhotoMap,
	ContainerTextBody,
	TextSpaceTitle,
	TextSpaceAddress,
	TextDescriptionPlace,
	ButtonSendMessage,
	TextSpaceMoreInformation,
	Line,
	ButtonTextSelected,
	ButtonTextNoSelected,
	ButtonFavorite,
	ButtonFrame,
	ButtonInterest,
} from "./styles";
import {
	SimpleLineIcons,
	FontAwesome,
	MaterialIcons,
} from "@expo/vector-icons";
import MoreInformations from "../../components/MoreInformations/MoreInformations";
import { PlaceDetailsProps } from "../../interfaces/PlaceDetailsProps/PlaceDetailsProps.interface";
import { ContactModel } from "../../interfaces/ContactModel/ContactModel.interface";
import UsersService from "../../services/UsersService";
import { Screens } from "../../interfaces/NavigationProps/NavigationProps.interface";

export default class PlaceDetails extends React.Component<PlaceDetailsProps> {
	state = {
		optionSelected: "Fotos",
		favorite: false,
	};

	private getPeopleInformationText() {
		const people = this.props.route?.params?.specs.size;

		if (people != 1) {
			return people + " pessoas";
		} else {
			return people + " pessoa";
		}
	}

	private genMoreInformationProps() {
		return [
			{
				iconName: "people",
				body: this.getPeopleInformationText(),
				color: colors.primary,
				size: 15,
				fontSize: "14px",
			},
			{
				iconName: "crop",
				body: this.props.route?.params?.specs.size + " m²",
				color: colors.primary,
				size: 15,
				fontSize: "14px",
			},
		];
	}

	render() {
		const { favorite, optionSelected } = this.state;
		return (
				<PageContainer indicatorStyle="black">
					<ButtonFavorite
						onPress={() => {
							this.setState({ favorite: !favorite });
						}}
					>
						<MaterialIcons
							name={favorite ? "favorite" : "favorite-border"}
							size={38}
							color="#05BDDA"
						/>
					</ButtonFavorite>
					<ContainerPhotoMap>
						{optionSelected === "Fotos" ? (
							<Carousel images={this.props.route?.params?.specs.imageURL} />
						) : (
							<Maps place={this.props.route?.params?.specs} />
						)}
					</ContainerPhotoMap>

					<ButtonContainer>
						{optionSelected === "Fotos" ? (
							<>
								<ButtonSelected
									onPress={() => {
										this.setState({ optionSelected: "Fotos" });
									}}
								>
									<ButtonFrame>
										<FontAwesome name="photo" size={16} color={"#FFFFFF"} />
									</ButtonFrame>
									<ButtonTextSelected>Fotos</ButtonTextSelected>
								</ButtonSelected>
								<ButtonNoSelected
									onPress={() => {
										this.setState({ optionSelected: "Mapa" });
									}}
								>
									<ButtonFrame>
										<SimpleLineIcons name="map" size={16} color={"#05BDDA"} />
									</ButtonFrame>
									<ButtonTextNoSelected>Mapa</ButtonTextNoSelected>
								</ButtonNoSelected>
							</>
						) : (
							<>
								<ButtonNoSelected
									onPress={() => {
										this.setState({ optionSelected: "Fotos" });
									}}
								>
									<ButtonFrame>
										<FontAwesome name="photo" size={16} color={"#05BDDA"} />
									</ButtonFrame>
									<ButtonTextNoSelected>Fotos</ButtonTextNoSelected>
								</ButtonNoSelected>
								<ButtonSelected
									onPress={() => {
										this.setState({ optionSelected: "Mapa" });
									}}
								>
									<ButtonFrame>
										<SimpleLineIcons name="map" size={16} color={"#FFFFFF"} />
									</ButtonFrame>
									<ButtonTextSelected>Mapa</ButtonTextSelected>
								</ButtonSelected>
							</>
						)}
					</ButtonContainer>

					<ContainerTextBody>
						<TextSpaceTitle fontSize="17px" fontWeight="bold" key="SpaceTitle">
							{this.props.route?.params?.specs.title}
						</TextSpaceTitle>
						<TextSpaceAddress fontSize="14px" key="SpaceAddress">
							{this.props.route?.params?.specs.address}
						</TextSpaceAddress>
						<TextSpaceMoreInformation>
							<MoreInformations informations={this.genMoreInformationProps()} />
						</TextSpaceMoreInformation>
						<Line />
						<TextDescriptionPlace textAlign="justify" fontSize="13px">
							{this.props.route?.params?.specs.description}
						</TextDescriptionPlace>
					</ContainerTextBody>
					<ButtonInterest>
						<ButtonSendMessage
							onPress={() => {
								const msg: string =
									"Olá! Estou interessado(a) no " +
									this.props.route?.params?.specs.title +
									" para o dia " +
									this.props.route?.params?.search.date +
									". Grato(a), aguardo confirmação de minha reserva!";
								const header: string =
									"Dados técnicos: \nId: " +
									this.props.route?.params?.specs.spaceId;
								let fullName = "";
								let email = "";
								let phoneNumber = "";
								if (UsersService.user) {
									fullName =
										UsersService.user.givenName +
										" " +
										UsersService.user.familyName;
									email = UsersService.user.email;
									phoneNumber = UsersService.user.phone;
								}
								const params: ContactModel = {
									message: msg,
									fullName: fullName,
									email: email,
									phoneNumber: phoneNumber,
									header: header,
									type: "interest",
									extra: { listingId: this.props.route?.params?.specs.spaceId },
								};
								this.props.navigation.navigate(Screens.Contact, {
									specs: params,
								});
							}}
						>
							Tenho Interesse
						</ButtonSendMessage>
					</ButtonInterest>
				</PageContainer>
		);
	}
}
