import React from "react";
import { createStackNavigator } from "@react-navigation/stack";
import {
	Screens,
	authSection,
	userSection,
	commonSection,
	authUserSection,
	coreSection,
} from "../interfaces/NavigationProps/NavigationProps.interface";

import HeaderV2 from "../components/HeaderV2/HeaderV2";
import HeaderV3 from "../components/HeaderV3/HeaderV3";
import HeaderTitleOnly from "../components/HeaderTitleOnly/HeaderTitleOnly";

import Home from "./Home/Home";
import Contact from "./Contact/Contact";
import AboutUs from "./AboutUs/AboutUs";
import HowItWorks from "./HowItWorks/HowItWorks";
import ListPlaces from "./ListPlaces/ListPlaces";
import PlaceDetails from "./PlaceDetails/PlaceDetails";
import RegisterUser from "./RegisterUser/RegisterUser";
import TermsOfUse from "./TermsOfUse/TermsOfUse";
import PrivacyPolicy from "./PrivacyPolicy/PrivacyPolicy";
import Login from "./LoginPage/LoginPage";

const HomeStack = createStackNavigator();
const AboutUsStack = createStackNavigator();
const HowItWorksStack = createStackNavigator();
const ContactStack = createStackNavigator();
const LoginStack = createStackNavigator();

export const defaultOptions = {
	headerTitle: () => <HeaderV3 />,
};

export const alternativeOptions = {
	headerTitle: () => <HeaderV2 />,
};

function HomeScreen() {
	return (
		<HomeStack.Navigator>
			<HomeStack.Screen
				name={Screens.Home}
				component={Home}
				options={defaultOptions}
			/>
			<HomeStack.Screen
				name={Screens.ListPlaces}
				component={ListPlaces}
				options={alternativeOptions}
			/>
			<HomeStack.Screen
				name={Screens.PlaceDetails}
				component={PlaceDetails}
				options={alternativeOptions}
			/>
			<HomeStack.Screen
				name={Screens.Contact}
				component={Contact}
				options={{
					headerTitle: () => <HeaderTitleOnly />,
					headerTitleAlign: "center",
				}}
			/>
		</HomeStack.Navigator>
	);
}

function BookScreen() {
	return undefined;
}

function PlaceScreen() {
	return undefined;
}

function AboutUsScreen() {
	return (
		<AboutUsStack.Navigator>
			<AboutUsStack.Screen
				name={Screens.AboutUs}
				component={AboutUs}
				options={defaultOptions}
			/>
		</AboutUsStack.Navigator>
	);
}

function LoginScreen() {
	return (
		<LoginStack.Navigator>
			<LoginStack.Screen
				name={Screens.Login}
				component={Login}
				options={defaultOptions}
			/>
			<LoginStack.Screen
				name={Screens.RegisterUser}
				component={RegisterUser}
				options={alternativeOptions}
			/>
			<LoginStack.Screen
				name={Screens.TermsOfUse}
				component={TermsOfUse}
				options={alternativeOptions}
			/>
			<LoginStack.Screen
				name={Screens.PrivacyPolicy}
				component={PrivacyPolicy}
				options={alternativeOptions}
			/>
		</LoginStack.Navigator>
	);
}

function HowItWorksScreen() {
	return (
		<HowItWorksStack.Navigator>
			<HowItWorksStack.Screen
				name={Screens.HowItWorks}
				component={HowItWorks}
				options={defaultOptions}
			/>
		</HowItWorksStack.Navigator>
	);
}

function ContactScreen() {
	return (
		<ContactStack.Navigator >
			<ContactStack.Screen
				name={Screens.Contact}
				component={Contact}
				options={defaultOptions}
			/>
		</ContactStack.Navigator>
	);
}

export const authScreens: authSection = {
	Login: { label: 'Entrar', component: LoginScreen },
	RegisterUser: { label: '', component: RegisterUser },
	PrivacyPolicy: { label: 'Política de Privacidade', component: PrivacyPolicy },
	TermsOfUse: { label: 'Termos de Uso', component: TermsOfUse },
};

export const userScreens: userSection = {
	Home: { label: 'Buscador De Espaços', component: HomeScreen },
};

export const commonScreens: commonSection = {
	Contact: { label: 'Contato', component: ContactScreen},
	AboutUs: { label: 'Sobre Nós', component: AboutUsScreen },
	HowItWorks: { label: 'Como funciona', component: HowItWorksScreen },
};

export const authUserScreens: authUserSection = {
	Book: { label: 'Minhas Reservas', component: BookScreen },
	Place: { label: 'Meus Locais', component: PlaceScreen }
}

export const coreScreens: coreSection = {
	ListPlaces: { label: 'Lugares', component: ListPlaces },
	PlaceDetails: { label: 'Detalhes', component: PlaceDetails },
}
