import { firestore, auth } from '../firebase/Firebase';
import { UserModel } from "../interfaces/UserModel/UserModel.interface";
import { IRegisterUser } from "../interfaces/RegisterUser/RegisterUser.interface";

class UsersService {
	user: UserModel | null;

	constructor() {
		this.user = null;
	}

	public async registerUser(values: IRegisterUser) {

		const { email, password, confirmPassword, ...rest } = values;

		const { user } = await auth.createUserWithEmailAndPassword(email, password);
		if (user) {
			const { uid } = user;
			await firestore.collection('users')
				.doc(uid)
				.set({
					user_uid: uid,
					...rest
				})
		}
		await this.loadUser();
	}

	public async loadUser() {
		const userObject = await firestore
			.collection('/users')
			.doc(auth.currentUser?.uid)
			.get();

		const userData = userObject.data();

		if (userData) {
			const user: UserModel = {
				email: auth.currentUser?.email || "",
				familyName: userData.familyName,
				givenName: userData.givenName,
				nationalId: userData.nationalId,
				phone: userData.phone,
				terms: userData.terms,
			}

			this.user = user;
		}
	}

	public async logout() {
		await auth.signOut();
		this.user = null;
	}

	public async login(email: string, password: string) {
		try {
			const login = await auth.signInWithEmailAndPassword(email, password);
			await this.loadUser();
			console.log("Sucesso: " + JSON.stringify(login));
			return true;

		} catch (error) {
			console.log("Error" + error);
			return false;
		}
	}
}
export default new UsersService();
